==> gmlutil-data-extraction-2.0.3.tar.gz: gmlutil-data-extraction-2.0.3/setup.py <==
from setuptools import setup

setup(
    name='gmlutil-data-extraction',
    version='2.0.3',    
    description='General Machine Learning Utility Package for Data Extraction',
    url='https://github.com/Phillip1982/gmlutil_data_extraction',
    author='Phillip Kim',
    author_email='phillip.kim@ejgallo.com',
    license='BSD 2-clause', ## Change this
    packages=['gmlutil_data_extraction'],
    install_requires=[ # package>=0.2,<0.3
		'botocore==1.35.0', # 1.29.7', # 1.23.24',
    	'aiobotocore==2.14.0', #2.5.0',
		'boto3==1.35.0', # 1.26.76', # 1.20.24', 
    	'awscli==1.34.0',# 1.27.76',
		'numpy==1.26.4',
		'pandas>2.1.0,<=2.2.2',
        'astropy>=6.0.0',
		'fuzzywuzzy>=0.18.0',
		'geopandas>=0.10.2',
        'hana-ml',
        'numba>=0.60.0',
        'oracledb>=1.4.2',
		'psycopg2-binary>=2.9.1',
        'pyarrow>=17.0.0',
        'pymssql>=2.2.1',
        'python-levenshtein-wheels>=0.13.1',
		'pytrends>=4.7.3',
        'redshift_connector>=2.0.916',
        'sagemaker>=2.229.0',
        'sagemaker-data-insights>=0.4.0',
		'sqlalchemy-redshift>=0.8.6'],
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Framework :: IPython',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
		'Operating System :: MacOS',
		'Operating System :: Microsoft :: Windows :: Windows XP',
        'Operating System :: POSIX :: Linux',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Programming Language :: Python :: 3.12'
    ],
)

==> gmlutil-data-extraction-2.1.0.tar.gz: gmlutil-data-extraction-2.1.0/setup.py <==
from setuptools import setup

setup(
    name='gmlutil-data-extraction',
    version='2.1.0',    
    description='General Machine Learning Utility Package for Data Extraction',
    url='https://git.ejgallo.com/prophet-data-science/central-data-science-library/gmlutil-data-extraction.git',
    author='Phillip Kim',
    author_email='phillip.kim@ejgallo.com',
    license='BSD 2-clause', ## Change this
    packages=['gmlutil_data_extraction'],
    install_requires=[ # package>=0.2,<0.3
        'setuptools==69.0.0',
		'botocore==1.35.0', # 1.29.7', # 1.23.24',
    	'aiobotocore==2.14.0', #2.5.0',
		'boto3==1.35.0', # 1.26.76', # 1.20.24', 
    	'awscli==1.34.0',# 1.27.76',
		'numpy==1.26.4',
		'pandas>2.1.0,<=2.2.2',
        'astropy>=6.0.0',
		'fuzzywuzzy>=0.18.0',
		'geopandas>=0.10.2',
        'hana-ml',
        'numba>=0.60.0',
        'oracledb>=1.4.2',
		'psycopg2-binary>=2.9.1',
        'pyarrow>=17.0.0',
        'pymssql>=2.2.1',
        'python-levenshtein-wheels>=0.13.1',
		'pytrends>=4.7.3',
        'redshift_connector>=2.1.5', # 2.0.916',
        'sagemaker>=2.229.0',
        'sagemaker-data-insights>=0.4.0',
		'sqlalchemy-redshift>=0.8.6'],
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Framework :: IPython',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
		'Operating System :: MacOS',
		'Operating System :: Microsoft :: Windows :: Windows XP',
        'Operating System :: POSIX :: Linux',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Programming Language :: Python :: 3.12'
    ],
)
